@@ -6,7 +6,7 @@ from os import getenv
 from typing import Dict
 from unittest.mock import Mock
 
-import requests
+from requests import Response, Session
 
 import pyinaturalist
 from pyinaturalist.constants import (
@@ -18,13 +18,11 @@ from pyinaturalist.constants import (
     MultiInt,
     RequestParams,
 )
-
-# from pyinaturalist.exceptions import TooManyRequests
-from pyinaturalist.forge_utils import copy_signature
+from pyinaturalist.docs import copy_signature
 from pyinaturalist.request_params import prepare_request
 
 # Mock response content to return in dry-run mode
-MOCK_RESPONSE = Mock(spec=requests.Response)
+MOCK_RESPONSE = Mock(spec=Response)
 MOCK_RESPONSE.json.return_value = {'results': [], 'total_results': 0, 'access_token': ''}
 
 logger = getLogger(__name__)
@@ -37,11 +35,13 @@ def request(
     access_token: str = None,
     user_agent: str = None,
     ids: MultiInt = None,
-    params: RequestParams = None,
     headers: Dict = None,
-    session: requests.Session = None,
-    **kwargs,
-) -> requests.Response:
+    json: Dict = None,
+    session: Session = None,
+    raise_for_status: bool = True,
+    timeout: float = 5,
+    **params: RequestParams,
+) -> Response:
     """Wrapper around :py:func:`requests.request` that supports dry-run mode and rate-limiting,
     and adds appropriate headers.
 
@@ -49,48 +49,64 @@ def request(
         method: HTTP method
         url: Request URL
         access_token: access_token: the access token, as returned by :func:`get_access_token()`
-        user_agent: a user-agent string that will be passed to iNaturalist
+        user_agent: A custom user-agent string to provide to the iNaturalist API
         ids: One or more integer IDs used as REST resource(s) to request
-        params: Requests parameters
         headers: Request headers
+        json: JSON request body
         session: Existing Session object to use instead of creating a new one
+        timeout: Time (in seconds) to wait for a response from the server; if exceeded, a
+            :py:exc:`requests.exceptions.Timeout` will be raised.
+        params: All other keyword arguments are interpreted as request parameters
 
     Returns:
         API response
     """
-    url, params, headers = prepare_request(url, access_token, user_agent, ids, params, headers)
+    url, params, headers, json = prepare_request(
+        url,
+        access_token,
+        user_agent,
+        ids,
+        params,
+        headers,
+        json,
+    )
     session = session or get_session()
 
     # Run either real request or mock request depending on settings
     if is_dry_run_enabled(method):
         logger.debug('Dry-run mode enabled; mocking request')
-        log_request(method, url, params=params, headers=headers, **kwargs)
+        log_request(method, url, params=params, headers=headers)
         return MOCK_RESPONSE
     else:
         with ratelimit():
-            return session.request(method, url, params=params, headers=headers, **kwargs)
+            response = session.request(
+                method, url, params=params, headers=headers, json=json, timeout=timeout
+            )
+        if raise_for_status:
+            response.raise_for_status()
+        return response
 
 
 @copy_signature(request, exclude='method')
-def delete(url: str, **kwargs) -> requests.Response:
+def delete(url: str, **kwargs) -> Response:
     """Wrapper around :py:func:`requests.delete` that supports dry-run mode and rate-limiting"""
     return request('DELETE', url, **kwargs)
 
 
 @copy_signature(request, exclude='method')
-def get(url: str, **kwargs) -> requests.Response:
+def get(url: str, **kwargs) -> Response:
     """Wrapper around :py:func:`requests.get` that supports dry-run mode and rate-limiting"""
     return request('GET', url, **kwargs)
 
 
 @copy_signature(request, exclude='method')
-def post(url: str, **kwargs) -> requests.Response:
+def post(url: str, **kwargs) -> Response:
     """Wrapper around :py:func:`requests.post` that supports dry-run mode and rate-limiting"""
     return request('POST', url, **kwargs)
 
 
 @copy_signature(request, exclude='method')
-def put(url: str, **kwargs) -> requests.Response:
+def put(url: str, **kwargs) -> Response:
     """Wrapper around :py:func:`requests.put` that supports dry-run mode and rate-limiting"""
     return request('PUT', url, **kwargs)
 
@@ -123,14 +139,14 @@ def get_limiter():
         return None
 
 
-def get_session() -> requests.Session:
+def get_session() -> Session:
     """Get a Session object that will be reused across requests to take advantage of connection
     pooling. This is especially relevant for large paginated requests. If used in a multi-threaded
     context (for example, a :py:class:`~concurrent.futures.ThreadPoolExecutor`), a separate session
     is used for each thread.
     """
     if not hasattr(thread_local, "session"):
-        thread_local.session = requests.Session()
+        thread_local.session = Session()
     return thread_local.session
 
 
@@ -141,9 +157,7 @@ def is_dry_run_enabled(method: str) -> bool:
     """
     dry_run_enabled = pyinaturalist.DRY_RUN_ENABLED or env_to_bool('DRY_RUN_ENABLED')
     if method in WRITE_HTTP_METHODS:
-        return (
-            dry_run_enabled or pyinaturalist.DRY_RUN_WRITE_ONLY or env_to_bool('DRY_RUN_WRITE_ONLY')
-        )
+        return dry_run_enabled or pyinaturalist.DRY_RUN_WRITE_ONLY or env_to_bool('DRY_RUN_WRITE_ONLY')
     return dry_run_enabled
 
 
